#include "dvegas.h"

using namespace HepSource;

class MyIntegrand : public SmartIntegrand {
public:
    // constructor
    MyIntegrand() : SmartIntegrand(8, 8) { }

    virtual void calc(const std::vector<double>& x, const int k[],
                      const double& weight, double f[])
    {
        for(int i=0; i<int(x.size()); ++i)
            f[i] = x[i];
    }
};

int main()
{
    MyIntegrand i;

    i.setAdapt(6, false);
    i.setAdapt(5, false);

    i.newCorrelationBlock(); // blocks with no entries should be ignored
    i.newCorrelationBlock();
    i.addCorrelatedAxis(2);
    i.addCorrelatedAxis(0);
    i.addCorrelatedAxis(2);  // repeated adding of an axis is a no-op
    i.addCorrelatedAxis(5);

    i.newCorrelationBlock();
    i.addCorrelatedAxis(3);  // blocks with one entry should be ignored

    i.newCorrelationBlock();
    i.addCorrelatedAxis(1);
    i.addCorrelatedAxis(3);  // this should work, because the previous block is ignored
    i.addCorrelatedAxis(2);

    if(i.getContinuousDimensions() != 7) return -1;
    if(i.getAuxiliaryDimensions() != 1) return -1;
    if(i.getCorrelatedDimensions().size() != 2) return -1;
    if(i.getCorrelatedDimensions()[0] != 3) return -1;
    if(i.getCorrelatedDimensions()[1] != 5) return -1;

    double x[8] = {2., 0., 5., 1., 3., 4., 7.};
    double aux[1] = {6.};
    double weight = 1.;
    double f[8];

    i(x, 0, weight, aux, f);
    for(int j=0; j<8; ++j)
        if(f[j] != double(j)) return -1;

    return 0;
}
